@@ -4,6 +4,7 @@ import re
 from tempfile import NamedTemporaryFile
 from appdirs import user_config_dir
 import json
+
 try:
     from qgrid import show_grid
 except:
@@ -20,7 +21,11 @@ from sensiml.datamanager import (
     Projects,
     SegmenterSet,
 )
-from sensiml.datamanager.knowledgepack import get_knowledgepack, get_knowledgepacks
+from sensiml.datamanager.knowledgepack import (
+    get_knowledgepack,
+    get_knowledgepacks,
+    delete_knowledgepack,
+)
 from sensiml.datasets import DataSets
 from sensiml.connection import Connection
 
@@ -76,7 +81,6 @@ class SensiML(object):
 
         self._project = None
         self._pipeline = None
-        self._knowledgepack_list = None
         auth_url = server + "oauth/"
 
         self._connection = Connection(
@@ -107,28 +111,6 @@ class SensiML(object):
         except:
             pass
 
-    @property
-    def knowledgepack_list(self):
-        if self._knowledgepack_list is None:
-            self.knowledgepack_list = get_knowledgepacks(self._connection)
-
-        return self._knowledgepack_list
-
-    @knowledgepack_list.setter
-    def knowledgepack_list(self, value):
-        if value is None:
-            self._knowledgepack_list = None
-        else:
-            self._knowledgepack_list = value.rename(
-                columns={
-                    "name": "Name",
-                    "project_name": "Project",
-                    "sandbox_name": "Pipeline",
-                    "uuid": "kp_uuid",
-                    "created_at": "Created",
-                }
-            )
-
     def validate_client_version(self, skip_validate=True):
         """ Perform a Validation check to see if this version of SensiML is up to date with the latest. """
 
@@ -259,30 +241,6 @@ class SensiML(object):
             }
         )
 
-    def list_knowledgepacks(self, unnamed=False):
-        """Lists all of the knowledgepacks associated with a team
-
-        Returns:
-            DataFrame: knowledgepacks on SensiML Cloud
-        """
-        if self.knowledgepack_list is None:
-            print("No Knowledgepacks stored for this team on the cloud.")
-            return None
-
-        knowledgepack_list = self.knowledgepack_list
-        knowledgepack_list = knowledgepack_list.rename(
-            columns={"knowledgepack_description": "kp_description"}
-        )
-
-        if unnamed:
-            return knowledgepack_list[
-                ["Name", "Created", "Project", "Pipeline", "kp_uuid", "kp_description"]
-            ]
-
-        return knowledgepack_list[knowledgepack_list["Name"] != ""][
-            ["Name", "Created", "Project", "Pipeline", "kp_uuid", "kp_description"]
-        ]
-
     def get_knowledgepack(self, uuid):
         """retrieve knowledgepack by uuid from the server associated with current project
 
@@ -295,11 +253,47 @@ class SensiML(object):
 
         return get_knowledgepack(uuid, self._connection)
 
+    def delete_knowledgepack(self, uuid):
+        """delete knowledgepack by uuid from the server associated with current project
+
+        Args:
+            uuid (str): unique identifier for knowledgepack
+
+        Returns:
+            TYPE: a knowledgepack object
+        """
+
+        return delete_knowledgepack(uuid, self._connection)
+
     @property
     def project(self):
         """The active project"""
         return self._project
 
+    def get_featurefile(self, uuid):
+        """Get a featruefile by uuid
+
+        Args:
+            get_objects (bool, False): Also return the featurefile objects.
+
+        """
+        if self._project is None:
+            raise Exception("Project must be set to perform this action.")
+
+        return self._project._feature_files.get_featurefile(uuid)
+
+    def get_datafile(self, uuid):
+        """Get a datafile by uuid
+
+        Args:
+            get_objects (bool, False): Also return the featurefile objects.
+
+        """
+        if self._project is None:
+            raise Exception("Project must be set to perform this action.")
+
+        return self._project._feature_files.get_featurefile(uuid)
+
     @print_list
     def list_featurefiles(self, get_objects=False, silent=False):
         """List all feature and data files for the active project.
@@ -323,7 +317,7 @@ class SensiML(object):
         if self._project is None:
             raise Exception("Project must be set to perform this action.")
 
-        return self._project._feature_files.build_featurefile_list()
+        return self._project._feature_files.build_datafile_list()
 
     @print_list
     def list_captures(self, get_objects=False):
@@ -402,7 +396,7 @@ class SensiML(object):
         combine_labels=None,
         force=False,
         renderer=None,
-        capture_configurations=""
+        capture_configurations="",
     ):
         """Create a query to use as input data in a pipeline.
 
@@ -419,7 +413,7 @@ class SensiML(object):
         """
 
         query = self.project.queries.get_query_by_name(name)
-        
+
         new = False
         if query is not None and not force:
             raise QueryExistsException(
@@ -431,8 +425,8 @@ class SensiML(object):
             query.metadata_filter = ""
             query.label_column = ""
             query.capture_configurations = ""
-            query.segmenter=None
-            
+            query.segmenter = None
+
         else:
             query = self.project.queries.new_query()
             query.name = name
@@ -475,14 +469,14 @@ class SensiML(object):
 
         return self.project.queries.get_query_by_name(name)
 
-    def upload_data_file(self, name, path, force=False):
+    def upload_data_file(self, name, path, force=False, is_features=False):
         """Upload data source from local CSV file"""
         logger.debug("set_feature_file:" + name + ":" + path)
         print('Uploading file "{}" to SensiML Cloud.'.format(name))
         if name[-4:] != ".csv":
             name = "{}.csv".format(name)
 
-        feature_file = self._project._feature_files.get_featurefile_by_name(name)
+        feature_file = self._project._feature_files.get_by_name(name)
         if feature_file is None:
             new = True
             feature_file = self._project.featurefiles.new_featurefile()
@@ -492,6 +486,7 @@ class SensiML(object):
                 raise FeatureFileExistsException()
 
         feature_file.filename = name
+        feature_file.is_features = is_features
         feature_file.path = path
         if new:
             feature_file.insert()
@@ -502,14 +497,14 @@ class SensiML(object):
 
         return self
 
-    def upload_dataframe(self, name, dataframe, force=False):
+    def upload_dataframe(self, name, dataframe, force=False, is_features=False):
         """Set data source from a pandas DataFrame."""
         logger.debug("set_data:" + name)
 
         with NamedTemporaryFile(delete=False) as temp:
             dataframe.to_csv(temp.name, index=False)
             logger.debug("set_dataframe:" + name + ":" + temp.name)
-            self.upload_data_file(name, temp.name, force=force)
+            self.upload_data_file(name, temp.name, force=force, is_features=is_features)
 
         os.remove(temp.name)
 
