@@ -81,7 +81,7 @@ class Connection(object):
                 config.load_from_file(path)
             except ConfigParser.NoSectionError:
                 config.create_config_object(path)
-                
+
             self.server_name = config.server
             self.server_url = config.url
             self.auth_url = config.auth_url
@@ -281,6 +281,8 @@ class Connection(object):
         Returns:
             Response
         """
+        print("DATA")
+        print(data)
         with open(file_path, read_type) as f:
 
             # TODO: Make this send params as body instead of headers.
@@ -306,29 +308,12 @@ class Connection(object):
 
             elif path.find("capture/") >= 0:
                 request = partial(
-                    self.request,
-                    method,
-                    path,
-                    files={"file": f},
-                    data={"name": data["name"], "asynchronous": data["asynchronous"]},
-                )
-
-            elif path.find("eventfile/") >= 0:
-                request = partial(
-                    self.request,
-                    method,
-                    path,
-                    files={"data_file": f},
-                    data={"name": data["name"]},
+                    self.request, method, path, files={"file": f}, data=data,
                 )
 
             elif path.find("featurefile/") >= 0:
                 request = partial(
-                    self.request,
-                    method,
-                    path,
-                    files={"data_file": f},
-                    data={"name": data["name"]},
+                    self.request, method, path, files={"data_file": f}, data=data,
                 )
             else:
                 request = partial(
@@ -425,4 +410,3 @@ class PagedRequest(object):
             )
         self.response.raise_for_status()
         return self.response.json()["results"]
-
