@@ -1,4 +1,3 @@
-
 from sensiml.datamanager.functions import Functions
 from sensiml.datamanager.platformdescriptions import PlatformDescriptions
 from sensiml.datamanager.pipelineseeds import PipelineSeeds
@@ -8,5 +7,12 @@ from sensiml.datamanager.segmenter import SegmenterSet
 from sensiml.datamanager.capture_configurations import CaptureConfigurations
 
 
-__all__ = ['Functions', 'FeatureFiles', 'Projects', 'SegmenterSet',
-           'PipelineSeeds', 'PlatformDescriptions', 'CaptureConfigurations']
+__all__ = [
+    "Functions",
+    "FeatureFiles",
+    "Projects",
+    "SegmenterSet",
+    "PipelineSeeds",
+    "PlatformDescriptions",
+    "CaptureConfigurations",
+]
