@@ -49,8 +49,12 @@ class Capture(object):
         self._path = path
         self._uuid = uuid
         self._capture_info = capture_info
-        self._metadata = MetadataRelationshipSet(self._connection, self._project, self, initialize_set=False)
-        self._segements = SegmentSet(self._connection, self._project, self, initialize_set=False)
+        self._metadata = MetadataRelationshipSet(
+            self._connection, self._project, self, initialize_set=False
+        )
+        self._segements = SegmentSet(
+            self._connection, self._project, self, initialize_set=False
+        )
 
     @property
     def uuid(self):
@@ -106,8 +110,7 @@ class Capture(object):
                 "CalculatedSampleRate"
             )
         if value.get("SampleRate", None) is not None:
-            self._capture_info["set_sample_rate"] = value.get(
-                "SampleRate", None)
+            self._capture_info["set_sample_rate"] = value.get("SampleRate", None)
         if value.get("capture_configuration_uuid", None) is not None:
             self._capture_info["capture_configuration_uuid"] = value.get(
                 "capture_configuration_uuid", None
@@ -173,8 +176,7 @@ class Capture(object):
         capture_info = {"name": self.filename, "asynchronous": asynchronous}
         if self.capture_info is not None:
             capture_info.update(self._capture_info)
-        response = self._connection.file_request(
-            url, self.path, capture_info, "rb")
+        response = self._connection.file_request(url, self.path, capture_info, "rb")
         response_data, err = utility.check_server_response(response)
         if err is False:
             self._uuid = response_data["uuid"]
