@@ -7,13 +7,14 @@ from sensiml.datamanager.base import Base
 class FeatureFile(Base):
     """Base class for a featurefile object."""
 
-    _fields = ["uuid", "name", "created_at", "last_modified"]
+    _fields = ["uuid", "name", "created_at", "last_modified", "is_features"]
 
-    def __init__(self, connection, project, name="", path=""):
+    def __init__(self, connection, project, name="", path="", is_features=True):
         self._connection = connection
         self._project = project
         self.uuid = None
         self._created_at = None
+        self._is_features = is_features
         self.name = name
         self.path = path
 
@@ -31,6 +32,16 @@ class FeatureFile(Base):
     def filename(self, value):
         self.name = value
 
+    @property
+    def is_features(self):
+        """If this is a DataFile or FeatureFile
+        """
+        return self._is_features
+
+    @is_features.setter
+    def is_features(self, value):
+        self._is_features = value
+
     @property
     def created_at(self):
         """Date of the Pipeline creation"""
@@ -45,7 +56,7 @@ class FeatureFile(Base):
     def insert(self):
         """Calls the REST API to insert a new featurefile."""
         url = "project/{0}/featurefile/".format(self._project.uuid)
-        featurefile_info = {"name": self.name}
+        featurefile_info = {"name": self.name, "is_features": self.is_features}
 
         if not os.path.exists(self.path):
             raise OSError(
@@ -63,7 +74,7 @@ class FeatureFile(Base):
     def update(self):
         """Calls the REST API to update the featurefile's properties on the server."""
         url = "project/{0}/featurefile/{1}/".format(self._project.uuid, self.uuid)
-        featurefile_info = {"name": self.name}
+        featurefile_info = {"name": self.name, "is_features": self.is_features}
 
         if not os.path.exists(self.path):
             raise OSError(
@@ -93,6 +104,7 @@ class FeatureFile(Base):
         response_data, err = utility.check_server_response(response)
         if err is False:
             self.name = response_data["name"]
+            self.is_features = response_data["is_features"]
 
         return response
 
