@@ -57,7 +57,7 @@ class Functions:
         for function in function_response:
             function_list[function.name] = function
 
-        self.function_list = function_list
+        self._function_list = function_list
 
     def get_function_by_name(self, name):
         """Gets a function from the server by name.
@@ -92,7 +92,7 @@ class Functions:
             Returns:
                 list of functions
         """
-        url = "transform"
+        url = "transform/"
         response = self._connection.request("get", url)
         try:
             response_data, err = utility.check_server_response(response)
