@@ -230,64 +230,6 @@ class KnowledgePack(VisualizeMixin):
         )
         return response.text
 
-    def get_positive_predictive_indexes(self, class_name, metric_set="validation"):
-        """
-        Returns the indicides of positive predictive classes, can be used to get the
-         feature vectors when running recall.
-
-
-        Args:
-            class_name (string): name of class to get indices for
-
-        """
-
-        count = 0
-        indexes = []
-        for i, pred in enumerate(self.model_results["metrics"][metric_set]["y_pred"]):
-            if pred == class_name:
-                indexes.append(i)
-
-        return indexes
-
-    def get_false_positive_indexes(self, class_name, metric_set="validation"):
-        """
-        Returns the indicides of false positives, can be used to get the
-         feature vectors when running recall.
-
-        Args:
-            class_name (string): name of class to get indices for
-
-
-        """
-        count = 0
-        indexes = []
-        for i, pred in enumerate(self.model_results["metrics"][metric_set]["y_pred"]):
-            if (
-                pred == class_name
-                and self.model_results["metrics"][metric_set]["y_true"][i] != class_name
-            ):
-                indexes.append(i)
-
-        return indexes
-
-    def get_true_positive_indexes(self, class_name, metric_set="validation"):
-        """
-         Returns the indicides of true positive classification, can be used to get the
-         feature vectors when running recall.
-
-        Args:
-            class_name (string): name of class to get indices for
-        """
-        indexes = []
-        for i, pred in enumerate(self.model_results["metrics"][metric_set]["y_pred"]):
-            if (
-                pred == class_name
-                and self.model_results["metrics"][metric_set]["y_true"][i] == class_name
-            ):
-                indexes.append(i)
-
-        return indexes
-
     def recognize_features(self, data):
         """Sends a single vector of features to the KnowledgePack for recognition.
 
@@ -491,6 +433,31 @@ class KnowledgePack(VisualizeMixin):
                 response_data, self._handle_result, silent=silent
             )
 
+    def delete(self):
+        """ Deletes the knowledgepack
+
+            Returns:
+                (DataFrame or ModelResultSet): result of executed pipeline, specified by the sandbox
+                (dict): execution summary including execution time and whether cache was used for each
+                step; also contains a feature cost table if applicable
+        """
+
+        uuids = {self.uuid}
+
+        if self.knowledgepack_description:
+            for _, value in self.knowledgepack_description.items():
+                uuids.add(value["uuid"])
+
+        for uuid in uuids:
+            url = "project/{0}/sandbox/{1}/knowledgepack/{2}/".format(
+                self._project_uuid, self._sandbox_uuid, uuid
+            )
+            response = self._connection.request("delete", url)
+            response, err = utility.check_server_response(response)
+            if err is False:
+                self._name = name
+                print("Knowledgepack " + uuid + " deleted.")
+
     def save(self, name):
         """Save a knowledpack with a name.
 
@@ -566,7 +533,6 @@ class KnowledgePack(VisualizeMixin):
             **kwargs
         )
 
-
     def download_binary(
         self, folder="", run_async=True, platform=None, renderer=None, *args, **kwargs
     ):
@@ -766,6 +732,16 @@ def get_knowledgepack(kp_uuid, connection):
         return kp
 
 
+def delete_knowledgepack(kp_uuid, connection):
+    """Gets a KnowledgePack by uuid.
+
+        Returns:
+            a KnowledgePack instance, list of instances, or None
+    """
+    url = "knowledgepack/{0}/".format(kp_uuid)
+    response = connection.request("delete", url)
+
+
 def get_knowledgepacks(connection):
     """Gets the KnowledgePack(s) created by the sandbox.
 
