@@ -1,8 +1,6 @@
-import json
-from numpy import float64, int64
 import sensiml.base.utility as utility
 import logging
-import time
+from sensiml.datamanager.base import Base, BaseSet
 
 
 logger = logging.getLogger(__name__)
@@ -14,9 +12,11 @@ class LabelValue(object):
     String = "string"
 
 
-class LabelValue(object):
+class LabelValue(Base):
     """Base class for a label object."""
 
+    _fields = ["uuid", "value", "created_at", "last_modified"]
+
     def __init__(self, connection, project, label):
         """Initialize a metadata object.
 
@@ -25,6 +25,9 @@ class LabelValue(object):
                 project
                 label
         """
+        if label._metadata:
+            raise Exception("Must be label not metadata")
+
         self._uuid = ""
         self._value = ""
         self._last_modified = ""
@@ -57,11 +60,15 @@ class LabelValue(object):
         """The creatd time of the label value object"""
         return self._created_at
 
+    @property
+    def label(self):
+
+        return self._label
+
     def insert(self):
         """Calls the REST API and inserts a metadata object onto the server using the local object's properties."""
-        url = "project/{0}/label/{1}/labelvalue/".format(
-            self._project.uuid,
-            self._label.uuid
+        url = "project/{0}/{1}/{2}/labelvalue/".format(
+            self._project.uuid, self._label._label_or_metadata, self._label.uuid
         )
         data = {
             "value": self.value,
@@ -71,12 +78,15 @@ class LabelValue(object):
         if err is False:
             self.uuid = response_data["uuid"]
 
+        return response
+
     def update(self):
         """Calls the REST API and updates the object on the server."""
-        url = "project/{0}/label/{1}/labelvalue/{2}".format(
+        url = "project/{0}/{1}/{2}/labelvalue/{3}".format(
             self._project.uuid,
+            self._label._label_or_metadata,
             self._label.uuid,
-            self.uuid
+            self.uuid,
         )
 
         data = {
@@ -86,28 +96,36 @@ class LabelValue(object):
         response = self._connection.request("put", url, data)
         response_data, err = utility.check_server_response(response)
 
+        return response
+
     def delete(self):
         """Calls the REST API and deletes the object from the server."""
-        url = "project/{0}/label/{1}/labelvalue/{2}".format(
+        url = "project/{0}/{1}/{2}/labelvalue/{3}".format(
             self._project.uuid,
+            self._label._label_or_metadata,
             self._label.uuid,
-            self.uuid
+            self.uuid,
         )
         response = self._connection.request("delete", url)
         response_data, err = utility.check_server_response(response)
 
+        return response
+
     def refresh(self):
         """Calls the REST API and populates the local object's properties from the server."""
-        url = "project/{0}/label/{1}/labelvalue/{2}".format(
+        url = "project/{0}/{1}/{2}/labelvalue/{3}".format(
             self._project.uuid,
+            self._label._label_or_metadata,
             self._label.uuid,
-            self.uuid
+            self.uuid,
         )
         response = self._connection.request("get", url)
         response_data, err = utility.check_server_response(response)
         if err is False:
             self.initialize_from_dict(response_data)
 
+        return response
+
     def initialize_from_dict(self, data):
         """Reads a json dictionary and populates a single metadata object.
 
@@ -116,10 +134,10 @@ class LabelValue(object):
         """
         self.uuid = data["uuid"]
         self.value = data["value"]
+        self._data = data
 
 
-class LabelValueSet(object):
-
+class LabelValueSet(BaseSet):
     def __init__(self, connection, project, label, initialize_set=True):
         """Initialize a metadata object.
 
@@ -131,40 +149,22 @@ class LabelValueSet(object):
         self._project = project
         self._label = label
         self._set = None
+        self._objclass = LabelValue
+        self._attr_key = "value"
 
         if initialize_set:
             self.refresh()
 
     @property
     def label_values(self):
-        if self._set is None:
-            self._set = self.get_set()
+        return self.objs
 
-        return self._set
-
-    def refresh(self):
-        self._set = self.get_set()
-
-    def get_set(self):
-        """Calls the REST API and inserts a metadata object onto the server using the local object's properties."""
-        url = "project/{0}/label/{1}/labelvalue/".format(
-            self._project.uuid,
-            self._label.uuid
+    @property
+    def get_set_url(self):
+        return "project/{0}/{1}/{2}/labelvalue/".format(
+            self._project.uuid, self._label._label_or_metadata, self._label.uuid
         )
 
-        response = self._connection.request("get", url)
-        response_data, err = utility.check_server_response(response)
-        if err:
-            print(err)
-            return None
-
-        # Populate each label from the server
-        labelvalues = []
-        for obj in response_data:
-            labelvalues.append(self._new_obj_from_dict(obj))
-
-        return labelvalues
-
     def _new_obj_from_dict(self, data):
         """Creates a new label from data in the dictionary.
 
@@ -175,20 +175,19 @@ class LabelValueSet(object):
                 label object
 
         """
-        labelvalue = LabelValue(self._connection, self._project, self._label)
-        labelvalue.initialize_from_dict(data)
-        return labelvalue
+
+        obj = self._objclass(self._connection, self._project, self._label)
+        obj.initialize_from_dict(data)
+        return obj
 
     def __str__(self):
         s = ""
         if self._set:
             label = self._set[0]._label
             s = "LABEL\n"
-            s += "\tname: " + str(label.name) + ' uuid: ' + \
-                str(label.uuid) + "\n"
+            s += "\tname: " + str(label.name) + " uuid: " + str(label.uuid) + "\n"
             s += "LABEL VALUES\n"
             for lbv in self._set:
-                s += "\tvalue: " + str(lbv.value) + \
-                    " uuid:" + str(lbv.uuid) + "\n"
+                s += "\tvalue: " + str(lbv.value) + " uuid:" + str(lbv.uuid) + "\n"
 
         return s
