@@ -106,8 +106,7 @@ class Query(object):
 
     @created_at.setter
     def created_at(self, value):
-        self._created_at = datetime.datetime.strptime(
-            value[:19], "%Y-%m-%dT%H:%M:%S")
+        self._created_at = datetime.datetime.strptime(value[:19], "%Y-%m-%dT%H:%M:%S")
 
     @property
     def label_column(self):
@@ -202,7 +201,6 @@ class Query(object):
 
         self._capture_configurations = json.dumps(value)
 
-
     @property
     def segmenter(self):
         """Segmenter to use for the query
@@ -233,12 +231,11 @@ class Query(object):
             "segmenter_id": self._segmenter,
             "label_column": self.label_column,
             "combine_labels": self.combine_labels,
-            "capture_configurations": self.capture_configurations
+            "capture_configurations": self.capture_configurations,
         }
 
         request = self._connection.request("post", url, data)
-        response, err = utility.check_server_response(
-            request, renderer=renderer)
+        response, err = utility.check_server_response(request, renderer=renderer)
         if err is False:
             self.uuid = response["uuid"]
             self._dirty = False
@@ -257,7 +254,7 @@ class Query(object):
             "segmenter_id": self._segmenter,
             "label_column": self.label_column,
             "combine_labels": self.combine_labels,
-            "capture_configurations": self.capture_configurations
+            "capture_configurations": self.capture_configurations,
         }
 
         if len(data["columns"]) > 0 or len(data["metadata_columns"]) > 0:
@@ -291,8 +288,7 @@ class Query(object):
         """Calls the REST API and deletes the query object from the server."""
         url = "project/{0}/query/{1}/".format(self._project.uuid, self.uuid)
         request = self._connection.request("delete", url)
-        response, err = utility.check_server_response(
-            request, renderer=renderer)
+        response, err = utility.check_server_response(request, renderer=renderer)
         self._dirty = False
         if err is False:
             print(response["result"])
@@ -300,11 +296,9 @@ class Query(object):
     def statistics_segments(self, renderer=None):
         """Returns metadata statistics for the query."""
 
-        url = "project/{0}/query/{1}/statistics/".format(
-            self._project.uuid, self.uuid)
+        url = "project/{0}/query/{1}/statistics/".format(self._project.uuid, self.uuid)
         request = self._connection.request("get", url)
-        response_data, err = utility.check_server_response(
-            request, renderer=renderer)
+        response_data, err = utility.check_server_response(request, renderer=renderer)
         if err is False:
             return DataFrame(response_data)
         else:
@@ -315,18 +309,15 @@ class Query(object):
         if self._dirty:
             self.update(renderer=renderer)
 
-        url = "project/{0}/query/{1}/statistics/".format(
-            self._project.uuid, self.uuid)
+        url = "project/{0}/query/{1}/statistics/".format(self._project.uuid, self.uuid)
         request = self._connection.request("get", url)
-        response_data, err = utility.check_server_response(
-            request, renderer=renderer)
+        response_data, err = utility.check_server_response(request, renderer=renderer)
         if err is False:
             df = DataFrame(response_data)
             df.drop("Segment Length", axis=1, inplace=True)
             data = (
                 df.groupby(
-                    ["Capture"] + self.metadata_columns._columns +
-                    [self.label_column]
+                    ["Capture"] + self.metadata_columns._columns + [self.label_column]
                 )[self.label_column]
                 .size()
                 .unstack(fill_value=0)
@@ -337,10 +328,10 @@ class Query(object):
             return None
 
     def plot_statistics(self, renderer=None, **kwargs):
-        """ Generates a bar plot of the query statistics """ 
+        """ Generates a bar plot of the query statistics """
         data = self.statistics(renderer=renderer)
         if data is not None:
-            data.sum().plot(kind='bar', **kwargs)
+            data.sum().plot(kind="bar", **kwargs)
 
     def data(self):
         """Calls the REST API for query execution and returns the result.
@@ -355,8 +346,7 @@ class Query(object):
         if self._dirty:
             self.update()
 
-        url = "project/{0}/query/{1}/data/".format(
-            self._project.uuid, self.uuid)
+        url = "project/{0}/query/{1}/data/".format(self._project.uuid, self.uuid)
         request = self._connection.request("get", url)
         response_data, err = utility.check_server_response(request)
         if err is False:
@@ -389,8 +379,7 @@ class Query(object):
         if self._dirty:
             self.update()
 
-        url = "project/{0}/query/{1}/size/".format(
-            self._project.uuid, self.uuid)
+        url = "project/{0}/query/{1}/size/".format(self._project.uuid, self.uuid)
         request = self._connection.request("get", url)
         response_data, err = utility.check_server_response(request)
         if not err:
@@ -414,7 +403,7 @@ class Query(object):
             self.metadata_filter = response["metadata_filter"]
             self.segmenter = response["segmenter_id"]
             self.combine_labels = response["combine_labels"]
-            self.capture_configurations = response['capture_configurations']
+            self.capture_configurations = response["capture_configurations"]
             self._dirty = False
 
     def initialize_from_dict(self, data):
@@ -428,15 +417,16 @@ class Query(object):
         self.label_column = data.get("label_column", "")
         self.segmenter = data.get("segmenter_id", None)
         self.combine_labels = data.get("combine_labels", None)
-        self.capture_configurations = data.get('capture_configurations', "")
+        self.capture_configurations = data.get("capture_configurations", "")
 
         self._dirty = False
 
     def post_feature_statistics(self, window_size=None):
         """Returns metadata statistics for the query."""
-        data = {'window_size': window_size}
+        data = {"window_size": window_size}
         url = "project/{0}/query/{1}/featurestatistics/".format(
-            self._project.uuid, self._uuid)
+            self._project.uuid, self._uuid
+        )
         response = self._connection.request("post", url, data)
 
         response_data, err = utility.check_server_response(response)
@@ -447,7 +437,8 @@ class Query(object):
     def get_feature_statistics(self):
         """Returns metadata statistics for the query."""
         url = "project/{0}/query/{1}/featurestatistics/".format(
-            self._project.uuid, self._uuid)
+            self._project.uuid, self._uuid
+        )
         response = self._connection.request("get", url)
         response_data, err = utility.check_server_response(response)
 
@@ -472,7 +463,7 @@ class Query(object):
             self.segmenter,
             self.label_column,
             self.combine_labels,
-            self.capture_configurations
+            self.capture_configurations,
         )
 
     def _to_dict(self):
@@ -483,5 +474,5 @@ class Query(object):
             "metadata_filter": self.metadata_filter,
             "segmenter_id": self.segmenter,
             "label_column": self.label_column,
-            "capture_configurations": self.capture_configurations
+            "capture_configurations": self.capture_configurations,
         }
