@@ -430,9 +430,7 @@ class Sandbox(object):
             Returns:
                 a KnowledgePack instance, list of instances, or None
         """
-        url = "knowledgepack/{0}/".format(
-            kp_uuid
-        )
+        url = "knowledgepack/{0}/".format(kp_uuid)
         response = self._connection.request("get", url)
         response_data, err = utility.check_server_response(response)
         if err is False:
@@ -580,8 +578,7 @@ class Sandbox(object):
 
     def auto(self, auto_params, seed, renderer=None):
         """Submits the automation job for asynchronous execution and returns the task status."""
-        # If the sandbox contains anything except a querycall or featurefilecall, and it
-        # is not a custom seed, do not execute the request
+
         if renderer is None:
             renderer = BaseRenderer()
         if seed.name == "Custom":
@@ -596,34 +593,11 @@ class Sandbox(object):
             renderer.render(
                 "Running Auto Pipeline with {} Seed and Auto Query:\n".format(seed.name)
             )
-        elif len(self.pipeline.to_list()) == 1 and self.pipeline.to_list()[0][
-            "type"
-        ] in ["query", "featurefile"]:
+
+        elif len(self.pipeline.to_list()) >= 1:
             renderer.render("Running Auto Pipeline with {} Seed:\n".format(seed.name))
             full_pipeline = deepcopy(self.pipeline.to_list()) + seed.pipeline
-        elif len(self.pipeline.to_list()) > 1 and self.pipeline.to_list()[0][
-            "type"
-        ] in ["query"]:
-            renderer.render("Running Auto Pipeline with {} Seed:\n".format(seed.name))
-            full_pipeline = deepcopy(self.pipeline.to_list()) + seed.pipeline
-        elif (
-            len(self.pipeline.to_list()) <= 2
-            and "segmenter" in [step["type"] for step in self.pipeline.to_list()]
-            and set([step["type"] for step in self.pipeline.to_list()]).issubset(
-                ["query", "featurefile", "segmenter"]
-            )
-        ):
-            segmenter_name = [
-                step["name"]
-                for step in self.pipeline.to_list()
-                if step["type"] == "segmenter"
-            ][0]
-            renderer.render(
-                "Running Auto Pipeline with {} Seed and {} Segmenter:\n".format(
-                    seed.name, segmenter_name
-                )
-            )
-            full_pipeline = deepcopy(self.pipeline.to_list()) + seed.pipeline
+
         else:
             renderer.render(
                 "This pipeline contains steps that could be overwritten by the {}\n".format(
@@ -853,11 +827,6 @@ def describe_pipeline(pipeline, show_params=True, show_set_params=False):
 def filter_params(inputs, num_tabs=1):
     not_params = [
         "input_data",
-        "group_column",
-        "passthrough_columns",
-        "group_columns",
-        "remove_columns",
-        "label_column",
         "feature_table",
     ]
     params = filter(lambda x: x not in not_params, inputs.keys())
@@ -886,4 +855,3 @@ def print_tvo(step):
         print("\t{0} {1}".format(map_tvo[tvo_step], step[tvo_step][0]["name"]))
         print(filter_params(step[tvo_step][0]["inputs"], num_tabs=2))
         print("")
-
