@@ -9,11 +9,19 @@ logger = logging.getLogger(__name__)
 class Segment(Base):
     """Base class for a label object."""
 
-    _fields = ["uuid","sample_start","sample_end","segmenter","label","label_value"]
+    _fields = [
+        "uuid",
+        "sample_start",
+        "sample_end",
+        "segmenter",
+        "label",
+        "label_value",
+    ]
 
-    _field_map = {"sample_start": "capture_sample_sequence_start",
-                  "sample_end": "capture_sample_sequence_end"
-                 }
+    _field_map = {
+        "sample_start": "capture_sample_sequence_start",
+        "sample_end": "capture_sample_sequence_end",
+    }
 
     def __init__(
         self, connection, project, capture, segmenter=None, label=None, label_value=None
