@@ -1,4 +1,3 @@
-
 from sensiml.method_calls.featurefilecall import FeatureFileCall
 from sensiml.method_calls.capturefilecall import CaptureFileCall
 from sensiml.method_calls.querycall import QueryCall
@@ -14,6 +13,18 @@ from sensiml.method_calls.optimizercall import OptimizerCall
 from sensiml.method_calls.trainingalgorithmcall import TrainingAlgorithmCall
 
 
-__all__ = ['FunctionCall', 'QueryCall', 'FeatureFileCall', 'TrainingAlgorithmCall',  \
-			'GeneratorCall', 'GeneratorCallSet', 'SelectorCall', 'SelectorCallSet', 'ValidationMethodCall', \
-			'ClassifierCall', 'OptimizerCall', 'TrainingAlgorithmCall', 'CaptureFileCall']
\ No newline at end of file
+__all__ = [
+    "FunctionCall",
+    "QueryCall",
+    "FeatureFileCall",
+    "TrainingAlgorithmCall",
+    "GeneratorCall",
+    "GeneratorCallSet",
+    "SelectorCall",
+    "SelectorCallSet",
+    "ValidationMethodCall",
+    "ClassifierCall",
+    "OptimizerCall",
+    "TrainingAlgorithmCall",
+    "CaptureFileCall",
+]
