@@ -604,7 +604,7 @@ class Pipeline(object):
         ).plot_features()
 
     def visualize_neuron_array(
-        self, model, feature_vector, featureX, featureY, neuron_alpha=0.2
+        self, model, feature_vector, featureX=None, featureY=None, neuron_alpha=0.2
     ):
         """Makes a plot of feature vectors by class to aid in understanding your model
 
@@ -626,6 +626,12 @@ class Pipeline(object):
                 )
                 return
 
+        feature_columns = [col for col in feature_vector.columns if col[:4] == "gen_"]
+        if featureX is None:
+            featureX = feature_columns[0]
+        if featureY is None:
+            featureY = feature_columns
+
         Visualize(
             model=model, feature_vector=feature_vector, label=self.label_column
         ).neuron_feature_map(featureX, featureY, neuron_alpha=neuron_alpha)
@@ -1064,10 +1070,7 @@ class Pipeline(object):
             if "Cascade" in transform["name"]:
                 self._group_columns.add("CascadeID")
 
-        if (
-            transform["name"] == "Feature Cascade"
-            and self.group_columns
-        ):
+        if transform["name"] == "Feature Cascade" and self.group_columns:
             self._group_columns.add("CascadeID")
 
     def _add_feature_generator(
@@ -1192,12 +1195,12 @@ class Pipeline(object):
     def features_to_tensor(
         self,
         feature_vectors,
-        validate=.1,
-        test=.1,
+        validate=0.1,
+        test=0.1,
         label=None,
         feature_columns=None,
         class_map=None,
-        dtype=int
+        dtype=int,
     ):
 
         if label is None:
@@ -1241,20 +1244,28 @@ class Pipeline(object):
         y_train, y_test, y_validate = np.split(
             y_values_encoded, [TRAIN_SPLIT, TEST_SPLIT]
         )
-                            
+
         print("-----  Summary  -----")
         print("Class Map:", class_map)
         print("Train:\n total: ", x_train.shape[0])
-        print(" by class:",y_train.sum(axis=0))
+        print(" by class:", y_train.sum(axis=0))
 
         print("Validate:\n total: ", x_validate.shape[0])
-        print(" by class:",y_validate.sum(axis=0))
+        print(" by class:", y_validate.sum(axis=0))
 
         print("Train:\n total: ", x_test.shape[0])
-        print(" by class:",y_test.sum(axis=0))     
+        print(" by class:", y_test.sum(axis=0))
+
+        return (
+            x_train.astype(dtype),
+            x_test.astype(dtype),
+            x_validate.astype(dtype),
+            y_train.astype(dtype),
+            y_test.astype(dtype),
+            y_validate.astype(dtype),
+            class_map,
+        )
 
-        return x_train.astype(dtype), x_test.astype(dtype), x_validate.astype(dtype), y_train.astype(dtype), y_test.astype(dtype), y_validate.astype(dtype), class_map
-        
 
 def get_contract_column_type(input_contract):
 
@@ -1291,4 +1302,3 @@ def generate_custom_feature_selector(feature_summary):
 def get_one_hot(targets, nb_classes):
     res = np.eye(nb_classes)[np.array(targets).reshape(-1)]
     return res.reshape(list(targets.shape) + [nb_classes])
-
