@@ -84,9 +84,7 @@ class AutoSenseWidget(BaseWidget):
         hierarchical_model = self._c_hierarchical_model.value
         balanced_data = self._c_balanced_data.value
         optimization_metric = self._w_optimization_metric.value.lower()
-        demean_segments = self._c_strip_mean.value
         outlier_filter = self._c_outlier_filter.value
-
         if self._w_combine_labels.value:
             combine_labels = json.loads(self._w_combine_labels.value)
         else:
@@ -125,7 +123,6 @@ class AutoSenseWidget(BaseWidget):
             "allow_unknown": allow_unk,
             "validation_method": validation_method,
             "balanced_data": balanced_data,
-            "demean_segments": demean_segments,
             "outlier_filter": outlier_filter,
             "single_model": single_model,
             "hierarchical_multi_model": hierarchical_model,
@@ -146,18 +143,30 @@ class AutoSenseWidget(BaseWidget):
             )
             return
 
-        if params['single_model']==False and params['hierarchical_multi_model']==False:
+        if (
+            params["single_model"] == False
+            and params["hierarchical_multi_model"] == False
+        ):
             self.renderer.render(
                 "\nERROR: Knowledge Pack Architecture was not selected. Select 'Single Model', 'Hierarchical Multi-Model' or Both.\n"
             )
             return
 
-        if sum([params['mutation_rate'], params['recreation_rate'], params['survivor_rate']])>0.95:
+        if (
+            sum(
+                [
+                    params["mutation_rate"],
+                    params["recreation_rate"],
+                    params["survivor_rate"],
+                ]
+            )
+            > 0.95
+        ):
             self.renderer.render(
                 "\nERROR: Summation of recreation_rate, mutation_rate and survivor_rate cannot be greater than 0.95.\n"
             )
             return
-           
+
         self._dsk.project.query_optimize()
 
         self._dsk.pipeline.reset()
@@ -168,12 +177,34 @@ class AutoSenseWidget(BaseWidget):
                 "Windowing", params={"window_size": delta, "delta": delta}
             )
 
+        if self._c_strip_mean.value:
+            self._dsk.pipeline.add_transform(
+                "Strip",
+                params={"input_columns": self.query.columns._columns, "type": "mean"},
+            )
+
+        if self._c_magnitude_transform.value:
+            magnitude_transform_number = len(
+                [
+                    pipeline_step["name"]
+                    for pipeline_step in self._dsk.pipeline._sandbox.pipeline.to_list()
+                    if pipeline_step["name"] == "Magnitude"
+                ]
+            )
+            self._dsk.pipeline.add_transform(
+                "Magnitude",
+                params={"input_columns": self.query.columns._columns},
+                overwrite=False,
+            )
+            params["input_columns"] = [
+                "Magnitude_ST_000" + str(magnitude_transform_number)
+            ]
+
         if seed_choice == "Custom Feature Generatorset":
             params[
                 "generatorset"
             ] = self.custom_feature_generator.get_fature_generator()
 
-
         print("Auto Sense Params", params)
         self._dsk.pipeline.describe()
 
@@ -257,8 +288,8 @@ class AutoSenseWidget(BaseWidget):
                 for x in self._dsk.pipeline.group_columns
                 if x not in [self._dsk.pipeline.label_column, "SegmentID"]
             ]
-            query = self._dsk.project.queries.get_or_create_query(change["new"])
-            if self._dsk.project.get_segmenters().loc[query.segmenter]["custom"]:
+            self.query = self._dsk.project.queries.get_or_create_query(change["new"])
+            if self._dsk.project.get_segmenters().loc[self.query.segmenter]["custom"]:
                 self._w_segment.options = ["", "Windowing", "Manual Segments"]
             else:
                 self._w_segment.options = ["", "Windowing", "Query Segmenter"]
@@ -355,9 +386,7 @@ class AutoSenseWidget(BaseWidget):
         )
 
         self._w_segment = widgets.Dropdown(
-            description="Segmenter",
-            options=["", "Windowing"],
-            style=description_style,
+            description="Segmenter", options=["", "Windowing"], style=description_style,
         )
 
         self._w_window_size = widgets.BoundedIntText(
@@ -511,7 +540,14 @@ class AutoSenseWidget(BaseWidget):
         self._info_strip_mean = widgets.Button(
             icon="question",
             disabled=True,
-            tooltip="Remove the mean from  each data source before before extracting features. This helps avoid overfitting models to noise and drift.",
+            tooltip="Remove the mean from  each data source before extracting features. This helps avoid overfitting models to noise and drift.",
+            layout=info_layout,
+        )
+
+        self._info_magnitude_transform = widgets.Button(
+            icon="question",
+            disabled=True,
+            tooltip="Apply magnitude transform to each data source. It merges all to the one before extracting features. This helps to create more robust model if location of the data source changes rotationally.",
             layout=info_layout,
         )
 
@@ -579,9 +615,7 @@ class AutoSenseWidget(BaseWidget):
 
         self._c_allow_unk = Checkbox(description="Allow Unknown", value=False)
 
-        self._c_single_model = Checkbox(
-            description="Single Model", value=True
-        )
+        self._c_single_model = Checkbox(description="Single Model", value=True)
 
         self._c_hierarchical_model = Checkbox(
             description="Hierarchical Multi-Model", value=False
@@ -593,6 +627,10 @@ class AutoSenseWidget(BaseWidget):
 
         self._c_outlier_filter = Checkbox(description="Filter Outliers", value=False)
 
+        self._c_magnitude_transform = Checkbox(
+            description="Magnitude Transform", value=False
+        )
+
         self._w_combine_labels = widgets.Text(description="Combine Labels", value="")
 
         self._w_validation_method = widgets.Dropdown(
@@ -805,6 +843,13 @@ class AutoSenseWidget(BaseWidget):
                             [self._c_allow_unk, self._info_allow_unk],
                             layout=Layout(align_self="flex-start"),
                         ),
+                        HBox(
+                            [
+                                self._c_magnitude_transform,
+                                self._info_magnitude_transform,
+                            ],
+                            layout=Layout(align_self="flex-start"),
+                        ),
                         # HBox([self._w_combine_labels],
                         #     layout=Layout(align_self='flex-start')),
                         widgets.HTML("<b>Feature Extractors</b>"),
@@ -836,7 +881,6 @@ class AutoSenseWidget(BaseWidget):
                         ),
                     ]
                 ),
-
                 HBox(
                     [
                         VBox(
@@ -851,7 +895,10 @@ class AutoSenseWidget(BaseWidget):
                                     layout=Layout(align_self="flex-start"),
                                 ),
                                 HBox(
-                                    [self._w_recreation_rate, self._info_recreation_rate],
+                                    [
+                                        self._w_recreation_rate,
+                                        self._info_recreation_rate,
+                                    ],
                                     layout=Layout(align_self="flex-start"),
                                 ),
                                 HBox(
@@ -864,25 +911,26 @@ class AutoSenseWidget(BaseWidget):
                                 ),
                             ]
                         ),
-
                         VBox(
                             [
-                                widgets.HTML("<b>Knowledge Pack Architecture Setting</b>"),
+                                widgets.HTML(
+                                    "<b>Knowledge Pack Architecture Setting</b>"
+                                ),
                                 HBox(
                                     [self._c_single_model, self._info_single_model],
                                     layout=Layout(align_self="flex-start"),
                                 ),
                                 HBox(
-                                    [self._c_hierarchical_model, self._info_hierarchical_model],
+                                    [
+                                        self._c_hierarchical_model,
+                                        self._info_hierarchical_model,
+                                    ],
                                     layout=Layout(align_self="flex-start"),
                                 ),
-
                             ]
-                        )
-
+                        ),
                     ]
-                )
-
+                ),
             ]
         )
 
