@@ -142,9 +142,9 @@ class ModelExploreWidget(BaseWidget):
         return results.to_csv(results_file_path)
 
     def _clear_the_cache(self, b, recognize=True):
-        '''
+        """
             Delete the cache data for selected file
-        '''
+        """
 
         name = "Name"
         if self._w_file_list.value == "captures":
@@ -156,19 +156,31 @@ class ModelExploreWidget(BaseWidget):
             capture = None
             for capture in self._widget_capture_data.get_selected_df()[name].values:
                 model_results_folder = "model_results"
-                kp_folder = os.path.join(model_results_folder, self.kp.uuid )
+                kp_folder = os.path.join(model_results_folder, self.kp.uuid)
                 results_file_path = os.path.join(kp_folder, capture)
-                
+
                 if os.path.exists(results_file_path):
                     os.remove(results_file_path)
-                    self._widget_render_space.value = "The cache is cleaned for the model: " + self.kp.name + " and the file: "  + capture
-                    
+                    self._widget_render_space.value = (
+                        "The cache is cleaned for the model: "
+                        + self.kp.name
+                        + " and the file: "
+                        + capture
+                    )
+
                 else:
-                    self._widget_render_space.value = "There is no cached data for the model: " + self.kp.name + " and the file: "  + capture
-                
+                    self._widget_render_space.value = (
+                        "There is no cached data for the model: "
+                        + self.kp.name
+                        + " and the file: "
+                        + capture
+                    )
+
             if capture is None:
-                self._widget_render_space.value = "Please select the file to clean the cache." 
-            
+                self._widget_render_space.value = (
+                    "Please select the file to clean the cache."
+                )
+
     def _recognize_signal_all(self, b, recognize=True):
 
         name = "Name"
@@ -186,7 +198,7 @@ class ModelExploreWidget(BaseWidget):
 
             if capture is None:
                 self._widget_render_space.value = "Please select an input file."
-    
+
     @button_handling
     def _recognize_signal(self, capture_file, recognize=True):
 
@@ -246,7 +258,8 @@ class ModelExploreWidget(BaseWidget):
             ]
         else:
             ytick_labels = ["Unknown"] + [
-                self.kp.class_map[x] for x in sorted(self.kp.class_map, key=lambda x: int(x))
+                self.kp.class_map[x]
+                for x in sorted(self.kp.class_map, key=lambda x: int(x))
             ]
 
         self.results = post_process(self.results, self._w_post_process_steps.value)
@@ -514,7 +527,7 @@ class ModelExploreWidget(BaseWidget):
             tooltip="Uses a majority vote algorithm over past events in the buffer to determine the current classification. A buffer size of 1 is equivalent to no post processing.",
             layout=Layout(width="5%", align_self="flex-end"),
         )
-        
+
         self._button_recognize_signal_capturefile = Button(
             icon="play",
             tooltip="Run recognition against the provided test data by using selected model.",
@@ -610,7 +623,6 @@ class ModelExploreWidget(BaseWidget):
                                 self._info_validation_method_size,
                                 self._check_show_features,
                                 self._check_show_feature_values,
-            
                             ],
                             layout=Layout(width="100%"),
                         ),
@@ -662,12 +674,12 @@ def post_process(results, buffer):
     if buffer > results.shape[0]:
         buffer = results.shape[0]
 
-    post_processed_results = [-1] * (buffer-1)
+    post_processed_results = [-1] * (buffer - 1)
 
-    for i in range(0, results.shape[0] - buffer +1):
+    for i in range(0, results.shape[0] - buffer + 1):
         counts = np.bincount(results["Classification"].iloc[i : i + buffer].values)
         post_processed_results.append(np.argmax(counts))
-        
+
     results["Classification"] = post_processed_results
 
     return results[results["Classification"] != -1].reset_index(drop=True)
